LogRocketCustomEventBuilder class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getProperties(
) → Map< String, dynamic> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putBool(
String key, bool value) → void -
putDouble(
String key, double value) → void -
putInt(
String key, int value) → void -
putListBool(
String key, List< bool> value) → void -
putListDouble(
String key, List< double> value) → void -
putListInt(
String key, List< int> value) → void -
putListString(
String key, List< String> value) → void -
putRevenue(
double revenue) → void -
putString(
String key, String value) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited