LogRocketInterface class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
captureError(
Error error) → Future< void> -
captureException(
Exception exception, [StackTrace? stackTrace]) → Future< void> -
captureMessage(
LogRocketMessageBuilder builder) → Future< void> -
identify(
String userId, Map< String, String> ? userInfo) → Future<void> -
initialize(
LogRocketInitConfiguration configuration) → Future< bool> -
log(
LogRocketLogLevel logLevel, String message) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseViewCapture(
) → Future< void> -
registerWebView(
GlobalKey< State< key) → Future<StatefulWidget> >bool> -
shutdown(
) → Future< void> -
tagPage(
String page) → void -
toString(
) → String -
A string representation of this object.
inherited
-
track(
LogRocketCustomEventBuilder event) → Future< void> -
unpauseViewCapture(
) → Future< void> -
wrap(
LogRocketWrapConfiguration configuration, FutureOr< void> runner()) → Future<void> -
wrapAndInitialize(
LogRocketWrapConfiguration wrapConfiguration, LogRocketInitConfiguration initConfiguration, FutureOr< void> runner()) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited